DeserializeError

Enum DeserializeError 

pub enum DeserializeError {
    TooShort {
        got: usize,
        need: usize,
    },
    BadMagic,
    UnsupportedVersion(u8),
    ParameterMismatch {
        t: u8,
        d: u8,
    },
    InvalidPrecision(u8),
    LengthMismatch {
        got: usize,
        expected: usize,
    },
}
Error returned when deserializing a byte slice into an ExaLogLog sketch.

Variants



TooShort

Byte slice is shorter than the minimum header length.

Fields

got: usize

Bytes received.

need: usize

Bytes required (at minimum).



BadMagic

Magic prefix did not match.



UnsupportedVersion(u8)

Format version is not supported by this build.



ParameterMismatch

The encoded t or d parameter does not match what this type expects. ExaLogLog accepts (t=2, d=20); ExaLogLogFast accepts (t=2, d=24).

Fields

t: u8

Encoded t.

d: u8

Encoded d.



InvalidPrecision(u8)

Encoded p is outside the supported range.



LengthMismatch

Length of the byte slice does not match what p implies.

Fields

got: usize

Bytes received.

expected: usize

Bytes expected, given the encoded p.